@@ -1,8 +1,12 @@
 #' @importFrom stats sd
 
 binPurity <- function(mz,intensity,dp = 2){
-    intensity <- round(intensity)
+  intensity <- ceiling(intensity)
+  if (sum(intensity) > 1) {
     mzs <- unlist(map2(mz,intensity,~{rep(.x,.y)}))
     purity <- 1 - (sd(mzs)/(1*10^-dp))
-    return(purity)
+  } else {
+    purity <- 1
+  }
+  return(purity)
 }
\ No newline at end of file
